import {HttpClient, HttpHeaders} from '@angular/common/http';
import {Component, Inject} from '@angular/core';
import { FormGroup, FormBuilder, Validators } from '@angular/forms';
import {MAT_DIALOG_DATA, MatDialogRef} from '@angular/material/dialog';
import { CreateClientComponent } from '../create-client/create-client.component';

@Component({
  selector: 'app-edit-client',
  templateUrl: './edit-client.component.html',
  styleUrl: './edit-client.component.css'
})
export class EditClientComponent {
  clientForm!: FormGroup;
  parentUnits: any[] = []; // Array to store parent units fetched from API
  isEditMode: boolean; // Flag to check if it's edit mode

  constructor(
    private fb: FormBuilder,
    private dialogRef: MatDialogRef<CreateClientComponent>,
    private http: HttpClient,
    @Inject(MAT_DIALOG_DATA) public data: any // Inject data for edit mode

  ) {
    this.isEditMode = !!data?.uuid; // Check if uuid is passed to determine edit mode
    if (this.isEditMode) {
      this.loadData(data.uuid);
    }
  }

  ngOnInit(): void {
    this.loadParentUnits(); // Load parent units when component initializes
    this.clientForm = this.fb.group({
      organizationalUnit: [''],
      name: ['', Validators.required],
      serialNumber: [''],
      netiface: "eth0",
      netDriver: "e1000e",
      mac: "00:11:22:33:44:55",
      ip: "127.0.0.1",
      status: "test",
      menu: null,
      hardwareProfile: null,
    });
  }

  loadParentUnits() {
    const url = 'http://127.0.0.1:8080/organizational-units?page=1&itemsPerPage=30';

    this.http.get<any>(url).subscribe(
      response => {
        this.parentUnits = response['hydra:member'];
      },
      error => {
        console.error('Error fetching parent units:', error);
      }
    );
  }

  loadData(uuid: string) {
    const url = `http://127.0.0.1:8080/clients/${uuid}`;

    this.http.get<any>(url).subscribe(
      data => {
        this.clientForm.patchValue({
          name: data.name,
          organizationalUnit: data.organizationalUnit ? data.organizationalUnit['@id'] : ''
        });
      });
  }

  onSubmit() {
    console.log('Form data:', this.clientForm.value);
    if (this.clientForm.valid) {
      const formData = this.clientForm.value;

      if (this.isEditMode) {
        // Edit mode: Send PUT request to update the unit
        const putUrl = `http://127.0.0.1:8080/clients/${this.data.uuid}`;
        const headers = new HttpHeaders({ 'Content-Type': 'application/json' });

        this.http.patch<any>(putUrl, formData, { headers }).subscribe(
          response => {
            console.log('PUT successful:', response);
            this.dialogRef.close();
          },
          error => {
            console.error('Error al realizar PUT:', error);
          }
        );
      } else {
        // Create mode: Send POST request to create a new unit
        const postUrl = 'http://127.0.0.1:8080/clients';
        const headers = new HttpHeaders({ 'Content-Type': 'application/json' });

        this.http.post<any>(postUrl, formData, { headers }).subscribe(
          response => {
            console.log('POST successful:', response);
            this.dialogRef.close();
          },
          error => {
            console.error('Error al realizar POST:', error);
          }
        );
      }
    }
  }

  onNoClick(): void {
    this.dialogRef.close();
  }
}
