import { Component, EventEmitter, Inject, OnInit, Output } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { MAT_DIALOG_DATA, MatDialogRef } from '@angular/material/dialog';
import { UserService } from '../users.service';

interface UserGroup {
  '@id': string;
  name: string;
  role: string[];
}

@Component({
  selector: 'app-add-user-modal',
  templateUrl: './add-user-modal.component.html',
  styleUrls: ['./add-user-modal.component.css']
})
export class AddUserModalComponent implements OnInit {
  @Output() userAdded = new EventEmitter<void>();
  userForm: FormGroup;
  userGroups: UserGroup[] = [];
  organizationalUnits: any[] = [];

  constructor(
    public dialogRef: MatDialogRef<AddUserModalComponent>,
    @Inject(MAT_DIALOG_DATA) public data: any,
    private fb: FormBuilder,
    private userService: UserService // Inyecta el servicio
  ) {
    this.userForm = this.fb.group({
      username: ['', Validators.required],
      password: ['', Validators.required],
      role: ['', Validators.required],
      organizationalUnit: [[], Validators.required]
    });
  }

  ngOnInit(): void {
    this.userService.getUserGroups().subscribe((data) => {
      this.userGroups = data['hydra:member'];
    });
    this.userService.getOrganizationalUnits().subscribe((data) => {
      this.organizationalUnits = data['hydra:member'];
    });
   
  }

  onNoClick(): void {
    this.dialogRef.close();
  }

  onSubmit(): void {
    if (this.userForm.valid) {
      const userPayload = {
        username: this.userForm.value.username,
        allowedOrganizationalUnits: this.userForm.value.organizationalUnit,
        password: this.userForm.value.password,
        enabled: true,
        userGroups: [this.userForm.value.role ]
      };

      this.userService.addUser(userPayload).subscribe(
        response => {
          console.log('User playload:', userPayload);
          console.log('User added successfully:', response);
          this.userAdded.emit();
          this.dialogRef.close(this.userForm.value);
        },
        error => {
          console.error('Error adding user:', error);
          // Agregar alguna lógica para manejar el error en la interfaz de usuario
        }
      );
    }
  }
}
